const { v4 } = require('uuid')
const config = require('config')
const { get, set } = require('lodash')
const {
  services,
  authsome: authsomeHelper,
} = require('pubsweet-component-helper-service')

const notifications = require('./notifications/notifications')

const s3Config = get(config, 'pubsweet-component-aws-s3', {})
const mtsConfig = get(config, 'mts-service', {})
const MTSService = require('pubsweet-component-mts-package')

module.exports = models => async (req, res) => {
  const { collectionId, fragmentId } = req.params
  let collection, fragment

  try {
    collection = await models.Collection.find(collectionId)
    if (!collection.fragments.includes(fragmentId))
      return res.status(400).json({
        error: `Collection and fragment do not match.`,
      })
    fragment = await models.Fragment.find(fragmentId)

    const authsome = authsomeHelper.getAuthsome(models)
    const target = {
      fragment,
      path: req.route.path,
    }
    const canPost = await authsome.can(req.user, 'POST', target)
    if (!canPost)
      return res.status(403).json({
        error: 'Unauthorized.',
      })

    fragment.submitted = Date.now()
    fragment = await fragment.save()

    collection.status = 'technicalChecks'
    set(collection, 'technicalChecks.token', v4())
    await collection.save()

    const { journal, xmlParser, ftp } = mtsConfig
    const MTS = new MTSService(journal, xmlParser, s3Config, ftp)
    const packageFragment = {
      ...fragment,
      metadata: {
        ...fragment.metadata,
        customId: collection.customId,
      },
    }

    await MTS.sendPackage({ fragment: packageFragment })

    notifications.sendNotifications({
      fragment,
      collection,
      UserModel: models.User,
      isTechnicalCheck: true,
      baseUrl: services.getBaseUrl(req),
    })

    return res.status(200).json(fragment)
  } catch (e) {
    const notFoundError = await services.handleNotFoundError(e, 'Item')
    return res.status(notFoundError.status).json({
      error: notFoundError.message,
    })
  }
}
