import React from 'react'
import { compose, withHandlers } from 'recompose'
import { Icon, Button } from '@pubsweet/ui'
import { connect } from 'react-redux'
import styled from 'styled-components'
import { th } from '@pubsweet/ui-toolkit'
import { withRouter } from 'react-router-dom'
import ZipFiles from 'pubsweet-components-faraday/src/components/Files/ZipFiles'
import {
  Decision,
  Recommendation,
} from 'pubsweet-components-faraday/src/components'

import {
  canMakeDecision,
  canMakeRecommendation,
  canEditManuscript,
} from 'pubsweet-component-faraday-selectors/src'

const SideBarActions = ({
  project,
  version,
  goToEdit,
  canMakeDecision,
  canEditManuscript,
  canMakeRecommendation,
}) => (
  <Root>
    {canEditManuscript && (
      <Button
        data-test="button-edit-manuscript"
        onClick={goToEdit(project, version)}
        primary
      >
        Edit
      </Button>
    )}
    {canMakeDecision && (
      <Decision
        collectionId={project.id}
        fragmentId={version.id}
        modalKey={`decide-${version.id}`}
        status={project.status}
      />
    )}

    {canMakeRecommendation && (
      <Recommendation
        collectionId={project.id}
        fragmentId={version.id}
        modalKey={`recommend-${version.id}`}
      />
    )}
    <ZipFiles
      archiveName={`ID-${project.customId}`}
      collectionId={project.id}
      fragmentId={version.id}
    >
      <ClickableIcon>
        <Icon>download</Icon>
      </ClickableIcon>
    </ZipFiles>
  </Root>
)

export default compose(
  withRouter,
  connect((state, { project, version }) => ({
    canMakeDecision: canMakeDecision(state, project, version),
    canMakeRecommendation: canMakeRecommendation(state, project, version),
    canEditManuscript: canEditManuscript(state, project, version),
  })),
  withHandlers({
    goToEdit: ({ history }) => (project, version) => () => {
      history.push(`/projects/${project.id}/versions/${version.id}/submit`, {
        editMode: true,
      })
    },
  }),
)(SideBarActions)

// #region styled-components
const Root = styled.div`
  border-bottom: ${th('borderDefault')};
  display: flex;
  justify-content: flex-end;
  padding: ${th('subGridUnit')};
`

const ClickableIcon = styled.div`
  margin: 0 ${th('subGridUnit')};
  &:hover {
    opacity: 0.7;
  }
`
// #endregion
